'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _prismjs = require('prismjs');

var _prismjs2 = _interopRequireDefault(_prismjs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var DEFAULTS = {
	plugins: [],
	init: function init() {}
};

/**
 * Loads the provided <code>lang</code> into prism.
 *
 * @param <String> lang
 *		Code of the language to load.
 * @return <Object?> The prism language object for the provided <code>lang</code> code. <code>undefined</code> if the code is not known to prism.
 */
function loadPrismLang() {
	var lang = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'markup';

	var langObject = _prismjs2.default.languages[lang];
	if (langObject === undefined) {
		try {
			require('prismjs/components/prism-' + lang);
			return _prismjs2.default.languages[lang];
		} catch (e) {
			// nothing to do
		}
	}
	return langObject;
}

function loadPrismPlugin(name) {
	try {
		require('prismjs/plugins/' + name + '/prism-' + name);
	} catch (e) {
		throw new Error('Cannot load Prism plugin "' + name + '". Please check the spelling.');
	}
}

/**
 * Highlights the provided text using Prism.
 *
 * @param <String> text
 * 		The text to highlight.
 * @param <String> lang
 *		Code of the language to highlight the text in.
 * @return <String> If Prism can highlight <code>text</code> in using <code>lang</code>, the highlighted code. Unchanged <code>text</code> otherwise.
 */
function highlight(text) {
	var lang = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'markup';

	var prismLang = loadPrismLang(lang);
	if (prismLang) {
		return _prismjs2.default.highlight(text, prismLang);
	}
}

function markdownItPrism(markdownit, useroptions) {
	var options = Object.assign({}, DEFAULTS, useroptions);

	options.plugins.forEach(loadPrismPlugin);
	options.init(_prismjs2.default);

	// register ourselves as highlighter
	markdownit.options.highlight = highlight;
}

exports.default = markdownItPrism;
module.exports = exports['default'];